@@ -17,8 +17,8 @@ extern int domid, domid_backend;
 #include <stdbool.h>
 
 #include "xenctrl.h"
-#include "xs.h"
-#ifndef CONFIG_STUBDOM
+#include "xenstore.h"
+#if !defined(CONFIG_STUBDOM) && !defined(__NetBSD__)
 #include "blktaplib.h"
 #endif
 
